## 3.3.8 (2022-01-27)

Backport many `ParamSpec`-related changes to Python 2 (#7054)

## 3.3.7 (2022-01-19)

Use PEP 585 syntax in Python 2, `protobuf` & `_ast` stubs, where possible (#6949)

## 3.3.3 (2022-01-17)

Use `_typeshed.Self` in Python 2, too (#6932)

## 3.3.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

